example_render_objects library

Classes

BasicCustomPainter
BasicCustomPainterElement
BasicProxy
A widget that rotates its child by 45 degrees.
BubbleCloud
A multi-child layout that packs its children tightly together in a cloud formation, preventing overlap using a force-directed physics algorithm.
BubbleCloudParentData
Specialized ParentData to store the physics state of each child during the layout calculation pass.
DesktopPaneLayout
Displays 3 panes: content, a left pane, and a right pane - the left and right panes are optional.
DividerHitTestTarget
A custom HitTestTarget that acts as a proxy between the hit testing system, the gesture system, and the mouse tracking system.
RenderBasicCustomPainter
RenderBasicProxy
RenderBubbleCloud
RenderDesktopPaneLayout