childForSlot method

  1. @override
Widget? childForSlot(
  1. DesktopPaneSlot slot
)
override

Returns the widget that is currently occupying the provided slot.

The RenderObject configured by this class will be configured to have the RenderObject produced by the returned Widget in the provided slot.

Implementation

@override
Widget? childForSlot(DesktopPaneSlot slot) {
  switch (slot) {
    case DesktopPaneSlot.left:
      return leftPane;
    case DesktopPaneSlot.content:
      return contentPane;
    case DesktopPaneSlot.right:
      return rightPane;
  }
}