DesktopPaneLayout class
Displays 3 panes: content, a left pane, and a right pane - the left and right panes are optional.
This widget demonstrates how to create a slotted multi-child render object. A slotted render object
is one in which each child has a unique name/property, rather than belonging to an unbounded List
or other collection.
Slotted render objects are easier to create than collection-based render objects because slotted render object (and their elements) don't need to search through their children, or worry about optimizing which children are inflated at any given moment in time.
Note: A render object can combine slotted children with child collections - you don't have to pick just one or the other.
- Inheritance
Constructors
- DesktopPaneLayout({Key? key, required Widget contentPane, Widget? leftPane, Widget? rightPane})
-
const
Properties
- contentPane → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leftPane → Widget?
-
final
- rightPane → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
slots
→ Iterable<
DesktopPaneSlot> -
Returns a list of all available slots.
no setteroverride
Methods
-
childForSlot(
DesktopPaneSlot slot) → Widget? -
Returns the widget that is currently occupying the provided
slot.override -
createElement(
) → SlottedRenderObjectElement< DesktopPaneSlot, RenderBox> -
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
-
createRenderObject(
BuildContext context) → RenderDesktopPaneLayout -
Creates an instance of the RenderObject class that this
RenderObjectWidget represents, using the configuration described by this
RenderObjectWidget.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didUnmountRenderObject(
covariant RenderObject renderObject) → void -
This method is called when a RenderObject that was previously
associated with this widget is removed from the render tree.
The provided RenderObject will be of the same type as the one created by
this widget's createRenderObject method.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateRenderObject(
BuildContext context, covariant RenderDesktopPaneLayout renderObject) → void -
Copies the configuration described by this RenderObjectWidget to the
given RenderObject, which will be of the same type as returned by this
object's createRenderObject.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited