DividerHitTestTarget class
A custom HitTestTarget that acts as a proxy between the hit testing system, the gesture system, and the mouse tracking system.
- Inheritance
-
- Object
- MouseTrackerAnnotation
- DividerHitTestTarget
- Implemented types
Constructors
- DividerHitTestTarget(RenderDesktopPaneLayout renderObject, {required bool isLeft})
Properties
- cursor → MouseCursor
-
The mouse cursor for mouse pointers that are hovering over the region.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLeft → bool
-
final
- onEnter → PointerEnterEventListener?
-
Triggered when a mouse pointer, with or without buttons pressed, has
entered the region and validForMouseTracker is true.
finalinherited
- onExit → PointerExitEventListener?
-
Triggered when a mouse pointer, with or without buttons pressed, has
exited the region and validForMouseTracker is true.
finalinherited
- renderObject → RenderDesktopPaneLayout
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validForMouseTracker → bool
-
Whether this is included when MouseTracker collects the list of
annotations.
finalinherited
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
handleEvent(
PointerEvent event, HitTestEntry< HitTestTarget> entry) → void -
Override this method to receive events.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited